@@ -179,8 +179,8 @@ escchr:
 							cp |= (hexdigit(c) << i);
 						}
 						/* RFC8259 - 7. Strings - surrogates.
-						 * 0xd800 - 0xdb7f - high surrogates */
-						if (cp >= 0xd800 && cp <= 0xdb7f) {
+						 * 0xd800 - 0xdbff - high surrogates */
+						if (cp >= 0xd800 && cp <= 0xdbff) {
 							if ((c = GETNEXT()) != '\\') {
 								len += codepointtoutf8(cp, &str[len]);
 								goto chr;
